@@ -658,7 +658,7 @@ proxy_button_press_event_cb (GtkButton *button,
 			     gpointer user_data)
 {
 	if (event->button == 2) {
-		gtk_button_pressed (button);
+		g_signal_emit_by_name (button, "pressed", 0);
 	}
 
 	return FALSE;
@@ -670,7 +670,7 @@ proxy_button_release_event_cb (GtkButton *button,
 			       gpointer user_data)
 {
 	if (event->button == 2) {
-		gtk_button_released (button);
+		g_signal_emit_by_name (button, "released", 0);
 	}
 
 	return FALSE;
@@ -938,7 +938,6 @@ nautilus_window_initialize_menus (NautilusWindow *window)
 	gtk_ui_manager_add_ui_from_string (ui_manager, ui, -1, NULL);
 
 	nautilus_window_initialize_trash_icon_monitor (window);
-	nautilus_window_initialize_bookmarks_menu (window);
 }
 
 static GList *
