@@ -172,7 +172,7 @@ nautilus_window_slot_inactive (NautilusWindowSlot *slot)
 static void
 nautilus_window_slot_init (NautilusWindowSlot *slot)
 {
-	GtkWidget *content_box, *eventbox, *extras_vbox, *frame, *hsep;
+	GtkWidget *content_box, *eventbox, *extras_vbox, *frame;
 
 	content_box = gtk_vbox_new (FALSE, 0);
 	slot->content_box = content_box;
@@ -180,17 +180,13 @@ nautilus_window_slot_init (NautilusWindowSlot *slot)
 
 	frame = gtk_frame_new (NULL);
 	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-	gtk_box_pack_start (GTK_BOX (content_box), frame, TRUE, TRUE, 0);
-	gtk_widget_show (frame);
-
-	slot->view_box = gtk_vbox_new (FALSE, 0);
-	gtk_container_add (GTK_CONTAINER (frame), slot->view_box);
-	gtk_widget_show (slot->view_box);
+	gtk_box_pack_start (GTK_BOX (content_box), frame, FALSE, FALSE, 0);
+	slot->extra_location_frame = frame;
 
 	eventbox = gtk_event_box_new ();
-	slot->extra_location_event_box = eventbox;
 	gtk_widget_set_name (eventbox, "nautilus-extra-view-widget");
-	gtk_box_pack_start (GTK_BOX (slot->view_box), eventbox, FALSE, FALSE, 0);
+	gtk_container_add (GTK_CONTAINER (frame), eventbox);
+	gtk_widget_show (eventbox);
 
 	extras_vbox = gtk_vbox_new (FALSE, 6);
 	gtk_container_set_border_width (GTK_CONTAINER (extras_vbox), 6);
@@ -198,9 +194,9 @@ nautilus_window_slot_init (NautilusWindowSlot *slot)
 	gtk_container_add (GTK_CONTAINER (eventbox), extras_vbox);
 	gtk_widget_show (extras_vbox);
 
-	hsep = gtk_hseparator_new ();
-	gtk_box_pack_start (GTK_BOX (slot->view_box), hsep, FALSE, FALSE, 0);
-	slot->extra_location_separator = hsep;
+	slot->view_box = gtk_vbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (content_box), slot->view_box, TRUE, TRUE, 0);
+	gtk_widget_show (slot->view_box);
 
 	slot->title = g_strdup (_("Loading..."));
 }
@@ -389,16 +385,6 @@ nautilus_window_slot_update_icon (NautilusWindowSlot *slot)
 	}
 }
 
-static void
-title_changed_callback (NautilusView *view,
-			NautilusWindowSlot *slot)
-{
-        g_assert (NAUTILUS_IS_WINDOW (slot->pane->window));
-
-        nautilus_window_slot_update_title (slot);
-	nautilus_window_slot_update_icon (slot);
-}
-
 void
 nautilus_window_slot_is_in_active_pane (NautilusWindowSlot *slot,
 					gboolean is_active)
@@ -424,10 +410,6 @@ nautilus_window_slot_connect_content_view (NautilusWindowSlot *slot,
 {
 	NautilusWindow *window;
 
-	g_signal_connect (view, "title-changed",
-			  G_CALLBACK (title_changed_callback),
-			  slot);
-
 	window = slot->pane->window;
 	if (window != NULL && slot == nautilus_window_get_active_slot (window)) {
 		nautilus_window_connect_content_view (window, view);
@@ -440,8 +422,6 @@ nautilus_window_slot_disconnect_content_view (NautilusWindowSlot *slot,
 {
 	NautilusWindow *window;
 
-	g_signal_handlers_disconnect_by_func (view, G_CALLBACK (title_changed_callback), slot);
-
 	window = slot->pane->window;
 	if (window != NULL && window->details->active_pane && window->details->active_pane->active_slot == slot) {
 		nautilus_window_disconnect_content_view (window, view);
@@ -551,8 +531,7 @@ nautilus_window_slot_remove_extra_location_widgets (NautilusWindowSlot *slot)
 	gtk_container_foreach (GTK_CONTAINER (slot->extra_location_widgets),
 			       remove_all,
 			       slot->extra_location_widgets);
-	gtk_widget_hide (slot->extra_location_event_box);
-	gtk_widget_hide (slot->extra_location_separator);
+	gtk_widget_hide (slot->extra_location_frame);
 }
 
 void
@@ -561,8 +540,7 @@ nautilus_window_slot_add_extra_location_widget (NautilusWindowSlot *slot,
 {
 	gtk_box_pack_start (GTK_BOX (slot->extra_location_widgets),
 			    widget, TRUE, TRUE, 0);
-	gtk_widget_show (slot->extra_location_event_box);
-	gtk_widget_show (slot->extra_location_separator);
+	gtk_widget_show (slot->extra_location_frame);
 }
 
 void
